/*
 * Copyright (c) 2024. Proton AG
 *
 * This file is part of ProtonVPN.
 *
 * ProtonVPN is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * ProtonVPN is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ProtonVPN.  If not, see <https://www.gnu.org/licenses/>.
 */

package com.protonvpn.android.redesign.main_screen.ui

import com.protonvpn.android.auth.usecase.CurrentUser
import com.protonvpn.android.redesign.recents.usecases.RecentsManager
import com.protonvpn.android.redesign.vpn.ConnectIntent
import com.protonvpn.android.ui.storage.UiStateStorage
import dagger.Reusable
import kotlinx.coroutines.flow.first
import javax.inject.Inject

@Reusable
class ShouldShowcaseRecents @Inject constructor(
    private val recentsManager: RecentsManager,
    private val uiStateStorage: UiStateStorage,
    private val currentUser: CurrentUser,
) {

    suspend operator fun invoke(connectionCardIntent: ConnectIntent): Boolean {
        val needsShowcase = currentUser.vpnUserFlow.first()?.isUserPlusOrAbove == true &&
            !uiStateStorage.state.first().hasUsedRecents
        return needsShowcase &&
            recentsManager.getRecentsList(2).first()
                .any { it.connectIntent != connectionCardIntent }
    }
}
